@@ -45,8 +45,7 @@ PLATFORM_NAMES = {
 class NC_ABI_L1B(BaseFileHandler):
 
     def __init__(self, filename, filename_info, filetype_info):
-        super(NC_ABI_L1B, self).__init__(filename, filename_info,
-                                         filetype_info)
+        super(NC_ABI_L1B, self).__init__(filename, filename_info, filetype_info)
         # xarray's default netcdf4 engine
         self.nc = xr.open_dataset(self.filename,
                                   decode_cf=True,
@@ -218,5 +217,5 @@ class NC_ABI_L1B(BaseFileHandler):
     def __del__(self):
         try:
             self.nc.close()
-        except (IOError, OSError):
+        except (IOError, OSError, AttributeError):
             pass
