@@ -30,13 +30,15 @@ import os
 from satpy.composites import CompositorLoader, IncompatibleAreas
 from satpy.config import get_environ_config_dir
 from satpy.dataset import (DatasetID, MetadataObject, dataset_walker,
-                           replace_anc)
+                           replace_anc, combine_metadata)
 from satpy.node import DependencyTree
 from satpy.readers import DatasetDict, load_readers
 from satpy.resample import (resample_dataset,
                             prepare_resampler, get_area_def)
 from satpy.writers import load_writer
-from pyresample.geometry import AreaDefinition, BaseDefinition
+from pyresample.geometry import AreaDefinition, BaseDefinition, SwathDefinition
+
+import xarray as xr
 from xarray import DataArray
 import numpy as np
 import six
@@ -72,7 +74,7 @@ class Scene(MetadataObject):
     """
 
     def __init__(self, filenames=None, reader=None, filter_parameters=None, reader_kwargs=None,
-                 ppp_config_dir=get_environ_config_dir(),
+                 ppp_config_dir=None,
                  base_dir=None,
                  sensor=None,
                  start_time=None,
@@ -107,6 +109,8 @@ class Scene(MetadataObject):
 
         """
         super(Scene, self).__init__()
+        if ppp_config_dir is None:
+            ppp_config_dir = get_environ_config_dir()
         # Set the PPP_CONFIG_DIR in the environment in case it's used elsewhere in pytroll
         LOG.debug("Setting 'PPP_CONFIG_DIR' to '%s'", ppp_config_dir)
         os.environ["PPP_CONFIG_DIR"] = self.ppp_config_dir = ppp_config_dir
@@ -522,7 +526,13 @@ class Scene(MetadataObject):
         new_scn = self.copy()
         new_scn.wishlist = self.wishlist
         for area, dataset_ids in self.iter_by_area():
-            new_area = area[key] if area is not None else None
+            if area is not None:
+                # assume dimensions for area are y and x
+                one_ds = self[dataset_ids[0]]
+                area_key = tuple(sl for dim, sl in zip(one_ds.dims, key) if dim in ['y', 'x'])
+                new_area = area[area_key]
+            else:
+                new_area = None
             new_scn._slice_datasets(dataset_ids, key, new_area)
         return new_scn
 
@@ -898,11 +908,22 @@ class Scene(MetadataObject):
         if unload:
             self.unload(keepables=keepables)
 
-    def _resampled_scene(self, new_scn, destination_area, **resample_kwargs):
+    def _reduce_data(self, source_area, destination_area, dataset):
+        """Reduce data by slicing it."""
+        slice_x, slice_y = source_area.get_area_slices(destination_area)
+        source_area = source_area[slice_y, slice_x]
+        dataset = dataset.isel(x=slice_x, y=slice_y)
+        assert ('x', source_area.x_size) in dataset.sizes.items()
+        assert ('y', source_area.y_size) in dataset.sizes.items()
+        dataset.attrs['area'] = source_area
+
+        return dataset
+
+    def _resampled_scene(self, new_scn, destination_area, reduce_data=True,
+                         **resample_kwargs):
         """Resample `datasets` to the `destination` area."""
         new_datasets = {}
         datasets = list(new_scn.datasets.values())
-        max_area = None
         if isinstance(destination_area, (str, six.text_type)):
             destination_area = get_area_def(destination_area)
         if hasattr(destination_area, 'freeze'):
@@ -931,13 +952,11 @@ class Scene(MetadataObject):
             LOG.debug("Resampling %s", ds_id)
             source_area = dataset.attrs['area']
             try:
-                slice_x, slice_y = source_area.get_area_slices(
-                    destination_area)
-                source_area = source_area[slice_y, slice_x]
-                dataset = dataset.isel(x=slice_x, y=slice_y)
-                assert ('x', source_area.x_size) in dataset.sizes.items()
-                assert ('y', source_area.y_size) in dataset.sizes.items()
-                dataset.attrs['area'] = source_area
+                if reduce_data:
+                    dataset = self._reduce_data(source_area, destination_area, dataset)
+                    source_area = dataset.attrs['area']
+                else:
+                    LOG.debug("Data reduction disabled by the user")
             except NotImplementedError:
                 LOG.info("Not reducing data before resampling.")
             if source_area not in resamplers:
@@ -956,7 +975,8 @@ class Scene(MetadataObject):
                 replace_anc(res, pres)
 
     def resample(self, destination=None, datasets=None, generate=True,
-                 unload=True, resampler=None, **resample_kwargs):
+                 unload=True, resampler=None, reduce_data=True,
+                 **resample_kwargs):
         """Resample datasets and return a new scene.
 
         Args:
@@ -975,6 +995,8 @@ class Scene(MetadataObject):
                 ('nearest'). Other possible values include 'native', 'ewa',
                 etc. See the :mod:`~satpy.resample` documentation for more
                 information.
+            reduce_data (bool): Reduce data by matching the input and output
+                areas and slicing the data arrays (default: True)
             resample_kwargs: Remaining keyword arguments to pass to individual
                 resampler classes. See the individual resampler class
                 documentation :mod:`here <satpy.resample>` for available
@@ -990,7 +1012,7 @@ class Scene(MetadataObject):
         # we may have some datasets we asked for but don't exist yet
         new_scn.wishlist = self.wishlist.copy()
         self._resampled_scene(new_scn, destination, resampler=resampler,
-                              **resample_kwargs)
+                              reduce_data=reduce_data, **resample_kwargs)
 
         # regenerate anything from the wishlist that needs it (combining
         # multiple resolutions, etc.)
@@ -1024,6 +1046,93 @@ class Scene(MetadataObject):
             img.show()
         return img
 
+    def to_geoviews(self, gvtype=None, datasets=None, kdims=None, vdims=None, dynamic=False):
+        """Convert satpy Scene to geoviews.
+
+        Args:
+            gvtype (gv plot type):
+                One of gv.Image, gv.LineContours, gv.FilledContours, gv.Points
+                Default to :class:`geoviews.Image`.
+                See Geoviews documentation for details.
+            datasets (list): Limit included products to these datasets
+            kdims (list of str):
+                Key dimensions. See geoviews documentation for more information.
+            vdims : list of str, optional
+                Value dimensions. See geoviews documentation for more information.
+                If not given defaults to first data variable
+            dynamic : boolean, optional, default False
+
+        Returns: geoviews object
+
+        Todo:
+            * better handling of projection information in datasets which are
+              to be passed to geoviews
+
+        """
+        try:
+            import geoviews as gv
+            from cartopy import crs  # noqa
+        except ImportError:
+            import warnings
+            warnings.warn("This method needs the geoviews package installed.")
+
+        if gvtype is None:
+            gvtype = gv.Image
+
+        ds = self.to_xarray_dataset(datasets)
+
+        if vdims is None:
+            # by default select first data variable as display variable
+            vdims = ds.data_vars[list(ds.data_vars.keys())[0]].name
+
+        if hasattr(ds, "area") and hasattr(ds.area, 'to_cartopy_crs'):
+            dscrs = ds.area.to_cartopy_crs()
+            gvds = gv.Dataset(ds, crs=dscrs)
+        else:
+            gvds = gv.Dataset(ds)
+
+        if "latitude" in ds.coords.keys():
+            gview = gvds.to(gv.QuadMesh, kdims=["longitude", "latitude"], vdims=vdims, dynamic=dynamic)
+        else:
+            gview = gvds.to(gvtype, kdims=["x", "y"], vdims=vdims, dynamic=dynamic)
+
+        return gview
+
+    def to_xarray_dataset(self, datasets=None):
+        """Merge all xr.DataArrays of a scene to a xr.DataSet.
+
+        Parameters:
+            datasets (list):
+                List of products to include in the :class:`xarray.Dataset`
+
+        Returns: :class:`xarray.Dataset`
+
+        """
+        if datasets is not None:
+            datasets = [self[ds] for ds in datasets]
+        else:
+            datasets = [self.datasets.get(ds) for ds in self.wishlist]
+            datasets = [ds for ds in datasets if ds is not None]
+
+        ds_dict = {i.attrs['name']: i.rename(i.attrs['name']) for i in datasets if i.attrs.get('area') is not None}
+        mdata = combine_metadata(*tuple(i.attrs for i in datasets))
+        if mdata.get('area') is None or not isinstance(mdata['area'], SwathDefinition):
+            # either don't know what the area is or we have an AreaDefinition
+            ds = xr.merge(ds_dict.values())
+        else:
+            # we have a swath definition and should use lon/lat values
+            lons, lats = mdata['area'].get_lonlats()
+            if not isinstance(lons, DataArray):
+                lons = DataArray(lons, dims=('y', 'x'))
+                lats = DataArray(lats, dims=('y', 'x'))
+            # ds_dict['longitude'] = lons
+            # ds_dict['latitude'] = lats
+            ds = xr.Dataset(ds_dict, coords={"latitude": (["y", "x"], lats),
+                                             "longitude": (["y", "x"], lons)})
+
+        ds.attrs = mdata
+        return ds
+
     def images(self):
         """Generate images for all the datasets from the scene."""
         for ds_id, projectable in self.datasets.items():
